ConversionFailedException class

Exception thrown when an actual type conversion attempt fails.

This typically occurs when a matching converter exists, but the conversion logic encounters an error (e.g., due to incompatible values or invalid data).


Example:

throw ConversionFailedException(
  sourceType: Class.forObject(input),
  targetType: Class.forType(String),
  value: input,
  cause: FormatException('Invalid number format'),
);
Inheritance
Available extensions

Constructors

ConversionFailedException({Class? sourceType, required Class targetType, Object? value, Object? point})
Exception thrown when an actual type conversion attempt fails.

Properties

cause Object?
The underlying cause of this exception, if any.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The message describing the error.
finalinherited
point Object?
The cause of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType Class?
The source type from which we tried to convert.
final
stackTrace StackTrace
The associated stack trace.
finalinherited
targetType Class
The target type we attempted to convert to.
final
value Object?
The actual value that failed to convert.
final

Methods

getCause() Object
The cause of this exception, if any.
inherited
getMessage() String
The message associated with this exception.
inherited
getStackTrace() StackTrace
The stack trace associated with this exception.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printStackTrace([bool useErrorPrint = false]) → void

Available on Error, provided by the ErrorExtensions extension

Prints the error along with its stack trace.
printStackTrace([StackTrace? stacktrace, bool useErrorPrint = false]) → void

Available on Exception, provided by the ExceptionExtensions extension

Prints the exception and optional StackTrace if available.
printStackTrace([bool useErrorPrint = false]) → void

Available on RuntimeException, provided by the RuntimeExceptionExtensions extension

Extension on RuntimeException to support pretty stack trace printing.
printStackTrace([bool useErrorPrint = false]) → void

Available on Throwable, provided by the ThrowableExtensions extension

Extension on Throwable to support printing stack traces in a unified way.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited