get method
T
get()
Invokes the supplier and returns the result.
This method may throw any exception that occurs during execution of the underlying supplier function.
Implementation
T get() => this();
Invokes the supplier and returns the result.
This method may throw any exception that occurs during execution of the underlying supplier function.
T get() => this();